RISCV-Config
==============

RISC-V Configuration Validator 

LICENSE: BSD-3 Clause.

Latest Documentation of RISCV-Config:

  * `HTML <https://riscv-config.readthedocs.io/>`_
  * `PDF  <https://github.com/riscv/riscv-config/releases/latest/download/riscv_config.pdf>`_
